from nemonet.seleniumwebdriver.abstract_command import AbstractCommand
from nemonet.engines.graph import Action


class ReadAndStore(AbstractCommand):
    def execute_action(self, action: Action, driver):
        pass

    def command_name(self) -> str:
        return 'READ_AND_STORE'



import unittest

from nemonet.seleniumwebdriver.commands import Command


class MyTestCase(unittest.TestCase):

    def test_something(self):
        commando = Command()


if __name__ == '__main__':
    unittest.main()
